@@ -194,30 +194,22 @@ void PropagateUploadFileCommon::setDeleteExisting(bool enabled)
 
 void PropagateUploadFileCommon::start()
 {
+    if (!_item->_originalFile.isEmpty() && !_item->_renameTarget.isEmpty() && _item->_renameTarget != _item->_originalFile) {
+        const auto existingFile = propagator()->fullLocalPath(propagator()->adjustRenamedPath(_item->_originalFile));
+        const auto targetFile = propagator()->fullLocalPath(_item->_renameTarget);
+        QString renameError;
+        if (!FileSystem::rename(existingFile, targetFile, &renameError)) {
+            done(SyncFileItem::NormalError, renameError);
+            return;
+        }
+        emit propagator()->touchedFile(existingFile);
+        emit propagator()->touchedFile(targetFile);
+    }
+
     const auto path = _item->_file;
     const auto slashPosition = path.lastIndexOf('/');
     const auto parentPath = slashPosition >= 0 ? path.left(slashPosition) : QString();
 
-
-    if (!_item->_renameTarget.isEmpty() && _item->_file != _item->_renameTarget) {
-        // Try to rename the file
-        const auto originalFilePathAbsolute = propagator()->fullLocalPath(_item->_file);
-        const auto newFilePathAbsolute = propagator()->fullLocalPath(_item->_renameTarget);
-        const auto renameSuccess = QFile::rename(originalFilePathAbsolute, newFilePathAbsolute);
-        if (!renameSuccess) {
-            done(SyncFileItem::NormalError, "File contains trailing spaces and couldn't be renamed");
-            return;
-        }
-        _item->_file = _item->_renameTarget;
-        _item->_modtime = FileSystem::getModTime(newFilePathAbsolute);
-        Q_ASSERT(_item->_modtime > 0);
-        if (_item->_modtime <= 0) {
-            qCWarning(lcPropagateUpload()) << "invalid modified time" << _item->_file << _item->_modtime;
-            slotOnErrorStartFolderUnlock(SyncFileItem::NormalError, tr("File %1 has invalid modified time. Do not upload to the server.").arg(QDir::toNativeSeparators(_item->_file)));
-            return;
-        }
-    }
-
     SyncJournalFileRecord parentRec;
     bool ok = propagator()->_journal->getFileRecord(parentPath, &parentRec);
     if (!ok) {
@@ -319,7 +311,7 @@ void PropagateUploadFileCommon::slotComputeContentChecksum()
     // probably temporary one.
     _item->_modtime = FileSystem::getModTime(filePath);
     if (_item->_modtime <= 0) {
-        slotOnErrorStartFolderUnlock(SyncFileItem::NormalError, tr("File %1 has invalid modified time. Do not upload to the server.").arg(QDir::toNativeSeparators(_item->_file)));
+        slotOnErrorStartFolderUnlock(SyncFileItem::NormalError, tr("File %1 has invalid modification time. Do not upload to the server.").arg(QDir::toNativeSeparators(_item->_file)));
         return;
     }
 
@@ -394,7 +386,7 @@ void PropagateUploadFileCommon::slotStartUpload(const QByteArray &transmissionCh
         return slotOnErrorStartFolderUnlock(SyncFileItem::SoftError, tr("File Removed (start upload) %1").arg(fullFilePath));
     }
     if (_item->_modtime <= 0) {
-        slotOnErrorStartFolderUnlock(SyncFileItem::NormalError, tr("File %1 has invalid modified time. Do not upload to the server.").arg(QDir::toNativeSeparators(_item->_file)));
+        slotOnErrorStartFolderUnlock(SyncFileItem::NormalError, tr("File %1 has invalid modification time. Do not upload to the server.").arg(QDir::toNativeSeparators(_item->_file)));
         return;
     }
     Q_ASSERT(_item->_modtime > 0);
@@ -407,7 +399,7 @@ void PropagateUploadFileCommon::slotStartUpload(const QByteArray &transmissionCh
 
     _item->_modtime = FileSystem::getModTime(originalFilePath);
     if (_item->_modtime <= 0) {
-        slotOnErrorStartFolderUnlock(SyncFileItem::NormalError, tr("File %1 has invalid modified time. Do not upload to the server.").arg(QDir::toNativeSeparators(_item->_file)));
+        slotOnErrorStartFolderUnlock(SyncFileItem::NormalError, tr("File %1 has invalid modification time. Do not upload to the server.").arg(QDir::toNativeSeparators(_item->_file)));
         return;
     }
     Q_ASSERT(_item->_modtime > 0);
