@@ -128,6 +128,8 @@ public:
 
     void setModTime(const QString &relativePath, const QDateTime &modTime) override;
 
+    void setModTimeKeepEtag(const QString &relativePath, const QDateTime &modTime);
+
     FileInfo *find(PathComponents pathComponents, const bool invalidateEtags = false);
 
     FileInfo *createDir(const QString &relativePath);
@@ -350,6 +352,8 @@ public:
     qint64 bytesAvailable() const override;
     QByteArray _body;
 
+    QMap<QNetworkRequest::KnownHeaders, QByteArray> _additionalHeaders;
+
     static const int defaultDelay = 10;
 };
 
@@ -400,6 +404,16 @@ public:
     qint64 readData(char *, qint64) override { return 0; }
 };
 
+class FakeFileLockReply : public FakePropfindReply
+{
+    Q_OBJECT
+public:
+    FakeFileLockReply(FileInfo &remoteRootFileInfo,
+                      QNetworkAccessManager::Operation op,
+                      const QNetworkRequest &request,
+                      QObject *parent);
+};
+
 // A delayed reply
 template <class OriginalReply>
 class DelayedReply : public OriginalReply
